@@ -14,26 +14,13 @@
 /* Define if your system has a working fnmatch function.  */
 #define HAVE_FNMATCH	1
 
-/* Define if you have <sys/wait.h> that is POSIX.1 compatible.  */
-#define HAVE_SYS_WAIT_H	1
-
-/* Define if you have the vprintf function.  */
-#define HAVE_VPRINTF	1
-
-/* Define as the return type of signal handlers (int or void).  */
-#define RETSIGTYPE	void
-
 /* Define if you have the mkstemp function.  */
 #define HAVE_MKSTEMP	1
 
-/* Define if you can safely include both <sys/time.h> and <time.h>.  */
-#define TIME_WITH_SYS_TIME	1
-
 /* Define if your system has random(3) and srandom(3) */
+#if defined(__DJGPP__)
 #define HAVE_SRANDOM	1
-
-/* Define if your system has strerror(3) */
-#define HAVE_STRERROR 1
+#endif
 
 /* Define if you have the usleep function.  */
 #define HAVE_USLEEP	1
@@ -55,4 +42,3 @@
 
 /* Define if you have the <unistd.h> header file.  */
 #define HAVE_UNISTD_H		1
-
