@@ -249,7 +249,7 @@ static BOOL filename2short (const char *l, char *s, int len_s)
 	__dpmi_int (0x21, &r);
 
 	if (r.x.flags & 1) {		/* is carry flag set (-> error) ?  */
-		strncpy (s, l, len_s);
+		strncpy (s, l, len_s - 1);
 		s[len_s - 1] = '\0';
 		return 0;
 	} else {
@@ -266,7 +266,7 @@ static BOOL filename2short (const char *l, char *s, int len_s)
 {
 	int copied = GetShortPathName (l, s, len_s);
 	if (copied == 0 || copied >= len_s) {
-		strncpy (s, l, len_s);
+		strncpy (s, l, len_s - 1);
 		s[len_s - 1] = '\0';
 		return 0;
 	} else
@@ -277,7 +277,7 @@ static BOOL filename2short (const char *l, char *s, int len_s)
 
 static BOOL filename2short (const char *l, char *s, int len_s)
 {
-	strncpy (s, l, len_s);
+	strncpy (s, l, len_s - 1);
 	s[len_s - 1] = '\0';
 	return 1;
 }
@@ -706,7 +706,7 @@ void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 #ifdef _mikmod_amiga
 			system(command);
 			file = fopen(dest, "r");
-#elif defined(__WATCOMC__)||(defined(_WIN32)&&!defined(__LCC__))
+#elif defined(__WATCOMC__)||defined(_WIN32)
 			file = _popen (command, "r");
 #else
 			file = popen (command, "r");
@@ -714,6 +714,7 @@ void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 			stop_redirect();
 			free (command);
 
+			if (!file) goto done;
 			fgets(string, PATH_MAX + offset + 1, file);
 			while (!feof(file)) {
 				string[strlen(string) - 1] = 0;
@@ -737,6 +738,7 @@ void MA_FindFiles(PLAYLIST * pl, const CHAR *filename)
 #else
 			pclose(file);
 #endif
+done:			;
 
 #else /* Archive display, the Unix way */
 			int fd[2];
