@@ -233,12 +233,18 @@ void set_help(MENTRY *entry, const char *str, ...)
 
 static char *skip_number(char *str)
 {
-	while (str && *str == ' ')
+	if (!str) {
+		return NULL;
+	}
+	while (*str == ' ') {
 		str++;
-	while (str && isdigit((int)*str))
+	}
+	while (isdigit((unsigned char)*str)) {
 		str++;
-	while (str && *str == ' ')
+	}
+	while (*str == ' ') {
 		str++;
+	}
 	return str;
 }
 
@@ -281,7 +287,7 @@ static void get_drivers(MENTRY *entry)
 				if (*(start + x) == '(')
 					break;
 				if ((*(start + x)) == 'v' &&
-					isdigit((int)*(start + x + 1))) break;
+					isdigit((unsigned char) *(start + x + 1))) break;
 			}
 			while (x > 0 && *(start + x - 1) == ' ')
 				x--;
@@ -348,6 +354,7 @@ static void get_driver_options(MENTRY *entry, MENTRY *dr_entry)
 /* extract themes for the other menu */
 static void get_themes(MENTRY *entry)
 {
+	char *pos;
 	int i, j, len = 0;
 
 	for (i=0; i<cnt_themes; i++) {
@@ -358,15 +365,17 @@ static void get_themes(MENTRY *entry)
 		free (entry->text);
 	entry->text = (char *) malloc(sizeof(char) * (len + 15));
 	strcpy(entry->text, "T&heme  [%o]");
+	pos = entry->text + strlen(entry->text);
 	for (i=0; i<cnt_themes; i++) {
-		strcat(entry->text, "|");
-		strcat(entry->text,themes[i].color ? "(C) ":"(M) ");
+		strcpy(pos, "|");
+		strcpy(pos + 1, themes[i].color ? "(C) ":"(M) ");
+		pos += 5;
 
-		len = strlen(entry->text);
 		j = strlen (themes[i].name);
 		j = (j>32 ? 32:j);
-		strncat(entry->text, themes[i].name, j);
-		entry->text[len + j] = '\0';
+		memcpy(pos, themes[i].name, j);
+		pos += j;
+		*pos = '\0';
 	}
 }
 
@@ -563,7 +572,7 @@ static char *theme_uniq_name (char *src_name)
 	buf[THEME_NAME_LEN] = '\0';
 	for (pos = buf+strlen(buf)-1; pos>=buf && isspace((int)*pos); pos--)
 		*pos = '\0';
-	if (pos>buf && isdigit((int)*pos) && isdigit((int)*(pos-1)))
+	if (pos>buf && isdigit((unsigned char) *pos) && isdigit((unsigned char) *(pos-1)))
 		*(pos-2) = '\0';
 
 	if (strlen(buf) > THEME_NAME_LEN-5)
@@ -772,7 +781,7 @@ static void handle_menu(MMENU *mn)
 				dlg_message_open("Copy, edit, or delete the active theme?",
 								 "&Copy|&Edit|Delete|&Cancel", 3, 0,
 								 cb_themeedit, NULL);
-		  }
+		}
 		break;
 	}
 }
