@@ -1,6 +1,5 @@
-/*  MikMod example player
-        (c) 2003 Raphael Assenat -- see file AUTHORS for complete list.
-	(c) 1999 Miodrag Vallat and others - see file AUTHORS for
+/*  MikMod module player
+	(c) 1998 - 2000 Miodrag Vallat and others - see file AUTHORS for
 	complete list.
 
 	This program is free software; you can redistribute it and/or modify
@@ -15,13 +14,13 @@
  
 	You should have received a copy of the GNU General Public License
 	along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+	02111-1307, USA.
 */
 
 /*==============================================================================
 
-  $Id: mconfedit.h,v 1.2 2003/10/05 03:35:46 raph Exp $
+  $Id: mconfedit.h,v 1.1.1.1 2004/01/16 02:07:43 raph Exp $
 
   The config editor
 
@@ -34,9 +33,11 @@
 
 /* set help text of menu entry
    free old menu->help and malloc new entry */
-void set_help(MENTRY*,char*,...);
+void set_help(MENTRY * entry, const char *str, ...);
 
 /* open config editor */
 void config_open(void);
 
 #endif /* MCONFEDIT_H */
+
+/* ex:set ts=4: */
