@@ -30,27 +30,27 @@
 #  include "config.h"
 #endif
 
-#ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-#endif
-#ifdef HAVE_GETOPT_LONG_ONLY
-#  include <getopt.h>
-#else
-#  include "mgetopt.h"
-#endif
-#include <ctype.h>
-#ifndef _WIN32
-#  include <signal.h>
-#endif
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
+#ifdef HAVE_GETOPT_LONG_ONLY
+#  include <getopt.h>
+#else
+#  include "getopt_long.h"
+#endif
+#ifndef _WIN32
+#  include <signal.h>
+#endif
 #if defined(__OS2__)||defined(__EMX__)
 #  define INCL_DOS
 #  define INCL_KBD
 #  define INCL_DOSPROCESS
 #  include <os2.h>
+#  include <io.h>	/* unlink() */
+#elif defined HAVE_UNISTD_H
+#  include <unistd.h>
 #endif
 
 #if defined(__FreeBSD__)||defined(__NetBSD__)||defined(__OpenBSD__)
@@ -64,9 +64,6 @@
 #  endif
 #endif
 #if defined(__linux)
-#  ifdef BROKEN_SCHED
-#    define _P __P
-#  endif
 #  include <sched.h>
 #endif
 
@@ -261,21 +258,21 @@ static void exit_player(int exitcode, const char *message, ...)
 
 #ifndef _WIN32
 /* signal handlers */
-static RETSIGTYPE GotoNext(int signum)
+static void GotoNext(int signum)
 {
 	next = PL_CONT_NEXT;
 
 	signal(SIGUSR1, GotoNext);
 }
 
-static RETSIGTYPE GotoPrev(int signum)
+static void GotoPrev(int signum)
 {
 	next = PL_CONT_PREV;
 
 	signal(SIGUSR2, GotoPrev);
 }
 
-static RETSIGTYPE ExitGracefully(int signum)
+static void ExitGracefully(int signum)
 {
 	/* can't exit now if playing */
 	if (status.state == STATE_PLAY) {
