@@ -1,7 +1,7 @@
-/* config.h.  Generated manually for Windows/LCC. */
+/* config.h.  Generated manually for Windows. */
 
 /* Define if your libmikmod has MikMod_free (not found in <= 3.2.0-beta2). */
-#define HAVE_MIKMOD_FREE 1
+#define HAVE_MIKMOD_FREE
 
 /* Define the directory for shared data. */
 #undef PACKAGE_DATA_DIR
@@ -16,14 +16,11 @@
 #undef HAVE_SNPRINTF /* but we do define HAVE_VSNPRINTF */
 
 /* Define to 1 if you have the `srandom' function. */
-#undef HAVE_SRANDOM
+/* #undef HAVE_SRANDOM */
 
 /* Define to 1 if you have the <stdlib.h> header file. */
 #define HAVE_STDLIB_H
 
-/* Define to 1 if you have the `strerror' function. */
-#define HAVE_STRERROR
-
 /* Define to 1 if you have the <string.h> header file. */
 #define HAVE_STRING_H
 
@@ -33,11 +30,5 @@
 /* Define to 1 if you have the <sys/types.h> header file. */
 #define HAVE_SYS_TYPES_H
 
-/* Define to 1 if you have the `vprintf' function. */
-#define HAVE_VPRINTF
-
 /* Define to 1 if you have the `vsnprintf' function. */
 #define HAVE_VSNPRINTF
-
-/* Define as the return type of signal handlers (`int' or `void'). */
-#define RETSIGTYPE void
